aboutsummaryrefslogtreecommitdiff
path: root/src/soc/intel/common
diff options
context:
space:
mode:
authorSubrata Banik <subratabanik@google.com>2022-06-01 06:54:44 +0000
committerSubrata Banik <subratabanik@google.com>2022-06-04 14:44:04 +0000
commit0b92aa618fbb73363501b8bfb8e9f51bdd9e3b3e (patch)
treef73dce20d1a01981d62969afc3b043ca9329d74c /src/soc/intel/common
parentde91780c3089e8a46be8ee7a196acaefa6bcf115 (diff)
soc/intel: Rename heci_init to cse_init
This patch renames heci_init() to cse_init() as HECI initialization should have a bigger scope than just initializing the CSE (a.k.a HECI1 alone). BUG=none TEST=Able to build and boot google/taeko. Signed-off-by: Subrata Banik <subratabanik@google.com> Change-Id: Ic7edd55ccdcd70b244615fa06f81803a0ae6ce80 Reviewed-on: https://review.coreboot.org/c/coreboot/+/64854 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Eric Lai <eric_lai@quanta.corp-partner.google.com> Reviewed-by: Lean Sheng Tan <sheng.tan@9elements.com> Reviewed-by: Sean Rhodes <sean@starlabs.systems>
Diffstat (limited to 'src/soc/intel/common')
-rw-r--r--src/soc/intel/common/block/cse/cse.c4
-rw-r--r--src/soc/intel/common/block/include/intelblocks/cse.h8
2 files changed, 8 insertions, 4 deletions
diff --git a/src/soc/intel/common/block/cse/cse.c b/src/soc/intel/common/block/cse/cse.c
index d284a9d638..e01b1cf920 100644
--- a/src/soc/intel/common/block/cse/cse.c
+++ b/src/soc/intel/common/block/cse/cse.c
@@ -85,11 +85,11 @@ static uintptr_t get_cse_bar(pci_devfn_t dev)
}
/*
* Initialize the device with provided temporary BAR. If BAR is 0 use a
* default. This is intended for pre-mem usage only where BARs haven't been
* assigned yet and devices are not enabled.
*/
-void heci_init(uintptr_t tempbar)
+void cse_init(uintptr_t tempbar)
{
pci_devfn_t dev = PCH_DEV_CSE;
@@ -85,11 +85,11 @@ static uintptr_t get_cse_bar(pci_devfn_t dev)
}
/*
- * Initialize the device with provided temporary BAR. If BAR is 0 use a
+ * Initialize the CSE device with provided temporary BAR. If BAR is 0 use a
* default. This is intended for pre-mem usage only where BARs haven't been
* assigned yet and devices are not enabled.
diff --git a/src/soc/intel/common/block/include/intelblocks/cse.h b/src/soc/intel/common/block/include/intelblocks/cse.h
index 8fd8ba0e1a..28bc2503be 100644
--- a/src/soc/intel/common/block/include/intelblocks/cse.h
+++ b/src/soc/intel/common/block/include/intelblocks/cse.h
@@ -326,8 +326,12 @@ struct cse_boot_perf_rsp {
uint32_t timestamp[NUM_CSE_BOOT_PERF_DATA];
} __packed;
-/* set up device for use in early boot enviroument with temp bar */
-void heci_init(uintptr_t bar);
+/*
+ * Initialize the CSE device.
+ *
+ * Set up CSE device for use in early boot environment with temp bar.
+ */
+void cse_init(uintptr_t bar);
/*
* Send message from BIOS_HOST_ADDR to cse_addr.